# Changelog

## [0.4.0](https://github.com/yapweiyih/test/compare/v0.3.0...v0.4.0) (2026-01-02)


### Features

* remove func 3 ([c8736a9](https://github.com/yapweiyih/test/commit/c8736a9c54ffc64b9241062d4557370c1a26ebf8))

## [0.3.0](https://github.com/yapweiyih/test/compare/v0.2.0...v0.3.0) (2026-01-02)


### Features

* new func ([ff40e2b](https://github.com/yapweiyih/test/commit/ff40e2b505de98df38eba05a43c01a3b891d91dd))

## [0.2.0](https://github.com/yapweiyih/test/compare/v0.1.0...v0.2.0) (2026-01-02)


### Features

* add new CLI command ([dbd65b4](https://github.com/yapweiyih/test/commit/dbd65b4b7242158b41aaf600620a1aa4f46f37b3))
